@@ -38,11 +38,17 @@ fn run(t: &mut Activation, ds: Arc<Cap>, spec: UnixRelayListener) -> ActorResult
     let facet = t.facet.clone();
     t.linked_task(syndicate::name!("listener"), async move {
         let listener = bind_unix_listener(&PathBuf::from(path_str)).await?;
-        facet.activate(Account::new(syndicate::name!("readiness")), |t| {
-            tracing::info!("listening");
-            ds.assert(t, language(), &lifecycle::ready(&spec));
-            Ok(())
-        })?;
+
+        if !facet.activate(
+            Account::new(syndicate::name!("readiness")), |t| {
+                tracing::info!("listening");
+                ds.assert(t, language(), &lifecycle::ready(&spec));
+                Ok(())
+            })
+        {
+            return Ok(LinkedTaskTermination::Normal);
+        }
+
         loop {
             let (stream, _addr) = listener.accept().await?;
             let peer = stream.peer_cred()?;
@@ -50,23 +56,28 @@ fn run(t: &mut Activation, ds: Arc<Cap>, spec: UnixRelayListener) -> ActorResult
             let name = syndicate::name!(parent: parent_span.clone(), "conn",
                                         pid = ?peer.pid().unwrap_or(-1),
                                         uid = peer.uid());
-            facet.activate(Account::new(name.clone()), move |t| {
-                t.spawn(name, |t| {
-                    Ok(t.linked_task(tracing::Span::current(), {
-                        let facet = t.facet.clone();
-                        async move {
-                            tracing::info!(protocol = %"unix");
-                            let (i, o) = stream.into_split();
-                            run_connection(facet,
-                                           relay::Input::Bytes(Box::pin(i)),
-                                           relay::Output::Bytes(Box::pin(o)),
-                                           gatekeeper)?;
-                            Ok(LinkedTaskTermination::KeepFacet)
-                        }
-                    }))
-                });
-                Ok(())
-            })?;
+            if !facet.activate(
+                Account::new(name.clone()),
+                move |t| {
+                    t.spawn(name, |t| {
+                        Ok(t.linked_task(tracing::Span::current(), {
+                            let facet = t.facet.clone();
+                            async move {
+                                tracing::info!(protocol = %"unix");
+                                let (i, o) = stream.into_split();
+                                run_connection(facet,
+                                               relay::Input::Bytes(Box::pin(i)),
+                                               relay::Output::Bytes(Box::pin(o)),
+                                               gatekeeper);
+                                Ok(LinkedTaskTermination::KeepFacet)
+                            }
+                        }))
+                    });
+                    Ok(())
+                })
+            {
+                return Ok(LinkedTaskTermination::Normal);
+            }
         }
     });
     Ok(())
